/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 27/06/22.
//

#ifndef FGGL_AUDIO_OPENAL_MODULE_HPP
#define FGGL_AUDIO_OPENAL_MODULE_HPP

#include <array>
#include <string>
#include "fggl/audio/audio.hpp"
#include "fggl/audio/openal/audio.hpp"

namespace fggl::audio {

	struct OpenAL {
		constexpr static const char *name = "fggl::audio::OpenAL";
		constexpr static const std::array<modules::ModuleService, 1> provides = {
			SERVICE_AUDIO_PLAYBACK
		};
		constexpr static const std::array<modules::ModuleService, 1> depends = {
			modules::make_service("fggl::data::Storage")
		};
		static bool factory(modules::ModuleService name, modules::Services &serviceManager);
	};

	bool OpenAL::factory(modules::ModuleService service, modules::Services &services) {
		if (service == SERVICE_AUDIO_PLAYBACK) {
			auto storage = services.get<data::Storage>();
			services.bind<audio::AudioService, openal::AudioServiceOAL>(storage);
			return true;
		}
		return false;
	}

} // namespace fggl::audio

#endif //FGGL_AUDIO_OPENAL_MODULE_HPP
