/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 11/06/22.
//

#ifndef FGGL_DEBUG_LOGGING_HPP
#define FGGL_DEBUG_LOGGING_HPP

#include <string_view>



namespace fggl::debug {

	std::string demangle(const char* name);

	using FmtType = const std::string_view;
	enum class Level;

	template<typename ...T>
	void error(FmtType fmt, T &&...args);

	template<typename ...T>
	void warning(FmtType fmt, T &&...args);

	template<typename ...T>
	void info(FmtType fmt, T &&...args);

	template<typename ...T>
	void debug(FmtType fmt, T &&...args);

	template<typename ...T>
	void trace(FmtType fmt, T &&...args);

	template<typename ...T>
	void log(FmtType fmt, T &&...args);

	template<typename ...T>
	void log(Level level, FmtType fmt, T &&...args);
}

#include "fggl/debug/impl/logging_fmt.hpp"

#endif //FGGL_DEBUG_LOGGING_HPP
