/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 30/05/22.
//

#ifndef FGGL_PHYS_BULLET_PHYS_DRAW_HPP
#define FGGL_PHYS_BULLET_PHYS_DRAW_HPP

# if WIN32
	#include "bullet/LinearMath/btIDebugDraw.h"
# else
	#include "LinearMath/btIDebugDraw.h"
# endif

#include "fggl/gfx/ogl/types.hpp"

#include <array>
#include <variant>
#include <vector>

namespace fggl::debug {

	class BulletDebugDrawList : public btIDebugDraw {
		public:
			BulletDebugDrawList();
			virtual ~BulletDebugDrawList() = default;

			void drawLine(const btVector3& from, const btVector3& to, const btVector3& fromColour, const btVector3& toColour) override;
			void drawLine(const btVector3& from, const btVector3& to, const btVector3& colour) override;
			void drawSphere(const btVector3& p, btScalar radius, const btVector3& color) override;

			void drawTriangle(const btVector3& a, const btVector3& b, const btVector3& c, const btVector3& color, btScalar alpha) override;
			void drawContactPoint(const btVector3& PointOnB, const btVector3& normalOnB, btScalar distance, int lifeTime, const btVector3& color) override;

			void reportErrorWarning(const char* warningString) override;
			void draw3dText(const btVector3& location, const char* textString) override;

			inline void setDebugMode(int debugMode) override {
				m_mode = debugMode;
			}

			inline int getDebugMode() const override {
				return m_mode;
			}

		private:
			int m_mode;

	};
}

#endif //FGGL_PHYS_BULLET_PHYS_DRAW_HPP
